@@ -1,12 +1,9 @@
 use crate::{SecureChannelNewKeyExchanger, SecureChannelVault, SecureChannelWorker};
 use async_trait::async_trait;
-#[cfg(not(feature = "std"))]
-use ockam_core::compat::random;
+use ockam_core::compat::rand::random;
 use ockam_core::compat::{boxed::Box, vec::Vec};
-use ockam_core::{Address, LocalMessage, Message, Result, Routed, TransportMessage, Worker};
+use ockam_core::{Address, Encodable, LocalMessage, Result, Routed, TransportMessage, Worker};
 use ockam_node::Context;
-#[cfg(feature = "std")]
-use rand::random;
 use serde::{Deserialize, Serialize};
 use tracing::debug;
 
